@@ -4,7 +4,7 @@
 #'
 #' @param coloredmeshes, list of coloredmesh. A coloredmesh is a named list as returned by the coloredmesh.from.* functions. It has the entries 'mesh' of type tmesh3d, a 'col', which is a color specification for such a mesh.
 #'
-#' @param background string, background color passed to rgl::bg3d()
+#' @param background string, background color passed to \code{\link[rgl]{bg3d}}.
 #'
 #' @param skip_all_na logical, whether to skip (i.e., not render) meshes in the list that have the property 'morph_data_was_all_na' set to TRUE. Defaults to TRUE. Practically, this means that a hemisphere for which the data was not given is not rendered, instead of being rendered in a single color.
 #'
@@ -12,7 +12,7 @@
 #'
 #' @param draw_labels logical, whether to draw label text for the different views that show information on the view direction and hemisphere displayed in a subplot. Defaults to FALSE.
 #'
-#' @param rgloptions, named list. Parameters passed to [rgl::par3d()]. Defaults to the empty list.
+#' @param rgloptions, named list. Parameters passed to \code{\link[rgl]{par3d}}. Defaults to the empty list.
 #'
 #' @param rglactions, named list. A list in which the names are from a set of pre-defined actions. Defaults to the empty list.
 #'
@@ -33,7 +33,7 @@ brainview.si <- function(coloredmeshes, background="white", skip_all_na=TRUE, st
 #'
 #' @param coloredmeshes, list of coloredmesh. A coloredmesh is a named list as returned by the coloredmesh.from.* functions. It has the entries 'mesh' of type tmesh3d, a 'col', which is a color specification for such a mesh.
 #'
-#' @param background string, background color passed to rgl::bg3d()
+#' @param background string, background color passed to \code{\link[rgl]{bg3d}}.
 #'
 #' @param skip_all_na logical, whether to skip (i.e., not render) meshes in the list that have the property 'morph_data_was_all_na' set to TRUE. Defaults to TRUE. Practically, this means that a hemisphere for which the data was not given is not rendered, instead of being rendered in a single color.
 #'
@@ -41,17 +41,17 @@ brainview.si <- function(coloredmeshes, background="white", skip_all_na=TRUE, st
 #'
 #' @param draw_labels logical, whether to draw label text for the different views that show information on the view direction and hemisphere displayed in a subplot. Defaults to FALSE.
 #'
-#' @param x rotation x axis value, passed to [rgl::spin3d()]. Defaults to 0.
+#' @param x rotation x axis value, passed to \code{\link[rgl]{spin3d}}. Defaults to 0.
 #'
-#' @param y rotation y axis value, passed to [rgl::spin3d()]. Defaults to 1.
+#' @param y rotation y axis value, passed to \code{\link[rgl]{spin3d}}. Defaults to 1.
 #'
-#' @param z rotation z axis value, passed to [rgl::spin3d()]. Defaults to 0.
+#' @param z rotation z axis value, passed to \code{\link[rgl]{spin3d}}. Defaults to 0.
 #'
-#' @param rpm rotation rpm value, passed to [rgl::spin3d()]. Defaults to 15.
+#' @param rpm rotation rpm value, passed to \code{\link[rgl]{spin3d}}. Defaults to 15.
 #'
-#' @param duration rotation duration value, passed to [rgl::spin3d()]. Defaults to 20.
+#' @param duration rotation duration value, passed to \code{\link[rgl]{spin3d}}. Defaults to 20.
 #'
-#' @param rgloptions, named list. Parameters passed to [rgl::par3d()]. Defaults to the empty list.
+#' @param rgloptions, named list. Parameters passed to \code{\link[rgl]{par3d}}. Defaults to the empty list.
 #'
 #' @param rglactions, named list. A list in which the names are from a set of pre-defined actions. Defaults to the empty list.
 #'
@@ -72,7 +72,7 @@ brainview.sr <- function(coloredmeshes, background="white", skip_all_na=TRUE, st
 #'
 #' @param coloredmeshes, list of coloredmesh. A coloredmesh is a named list as returned by the coloredmesh.from.* functions. It has the entries 'mesh' of type tmesh3d, a 'col', which is a color specification for such a mesh.
 #'
-#' @param background string, background color passed to rgl::bg3d()
+#' @param background string, background color passed to \code{\link[rgl]{bg3d}}.
 #'
 #' @param skip_all_na logical, whether to skip (i.e., not render) meshes in the list that have the property 'morph_data_was_all_na' set to TRUE. Defaults to TRUE. Practically, this means that a hemisphere for which the data was not given is not rendered, instead of being rendered in a single color.
 #'
@@ -80,7 +80,7 @@ brainview.sr <- function(coloredmeshes, background="white", skip_all_na=TRUE, st
 #'
 #' @param draw_labels logical, whether to draw label text for the different views that show information on the view direction and hemisphere displayed in a subplot. Defaults to FALSE.
 #'
-#' @param rgloptions, named list. Parameters passed to [rgl::par3d()]. Defaults to the empty list.
+#' @param rgloptions, named list. Parameters passed to \code{\link[rgl]{par3d}}. Defaults to the empty list.
 #'
 #' @param rglactions, named list. A list in which the names are from a set of pre-defined actions. The values can be used to specify parameters for the action.
 #'
@@ -160,18 +160,28 @@ brainview.t4 <- function(coloredmeshes, background="white", skip_all_na=TRUE, st
 #'
 #' @param rglactions, named list. A list in which the names are from a set of pre-defined actions. The values can be used to specify parameters for the action.
 #'
+#' @param at_index integer, the index to use in case of vectorized entries. Allows using different output_images for different views or similar.
+#'
 #' @keywords internal
 #' @importFrom rgl rgl.snapshot
-perform.rglactions <- function(rglactions) {
+perform.rglactions <- function(rglactions, at_index=NULL) {
     if(is.list(rglactions)) {
         if("snapshot_png" %in% names(rglactions)) {
-            output_image = path.expand(rglactions$snapshot_png);
+            if(length(rglactions$snapshot_png) == 1 || is.null(at_index)) {
+                output_image = path.expand(rglactions$snapshot_png);
+            } else {
+                if(length(rglactions$snapshot_png) < at_index) {
+                    warning(sprintf("Requested rglaction at_index '%d' but only %d entries exist for action 'snapshot_png'.\n", at_index, length(rglactions$snapshot_png)));
+                }
+                output_image = path.expand(rglactions$snapshot_png[[at_index]]);
+            }
             rgl::rgl.snapshot(output_image, fmt="png");
             message(sprintf("Screenshot written to '%s' (current working dir is '%s').\n", output_image, getwd()));
         }
     }
 }
 
+
 #' @title Check for a key in names of rglactions.
 #'
 #' @param rglactions, named list. A list in which the names are from a set of pre-defined actions. The values can be used to specify parameters for the action.
@@ -191,7 +201,7 @@ rglactions.has.key <- function(rglactions, key) {
 #'
 #' @param coloredmeshes, list of coloredmesh. A coloredmesh is a named list as returned by the coloredmesh.from.* functions. It has the entries 'mesh' of type tmesh3d, a 'col', which is a color specification for such a mesh.
 #'
-#' @param background string, background color passed to rgl::bg3d()
+#' @param background string, background color passed to \code{\link[rgl]{bg3d}}.
 #'
 #' @param skip_all_na logical, whether to skip (i.e., not render) meshes in the list that have the property 'morph_data_was_all_na' set to TRUE. Defaults to TRUE. Practically, this means that a hemisphere for which the data was not given is not rendered, instead of being rendered in a single color.
 #'
@@ -199,7 +209,7 @@ rglactions.has.key <- function(rglactions, key) {
 #'
 #' @param draw_labels logical, whether to draw label text for the different views that show information on the view direction and hemisphere displayed in a subplot. Defaults to FALSE.
 #'
-#' @param rgloptions, named list. Parameters passed to [rgl::par3d()]. Defaults to the empty list. To increase plot resolution to 2000x1600 px, try: \code{rgloptions=list("windowRect"=c(50,50,2000,1600))}.
+#' @param rgloptions, named list. Parameters passed to \code{\link[rgl]{par3d}}. Defaults to the empty list. To increase plot resolution to 2000x1600 px, try: \code{rgloptions=list("windowRect"=c(50,50,2000,1600))}.
 #'
 #' @param rglactions, named list. A list in which the names are from a set of pre-defined actions. The values can be used to specify parameters for the action.
 #'
@@ -301,7 +311,7 @@ brainview.t9 <- function(coloredmeshes, background="white", skip_all_na=TRUE, st
     vis.rotated.coloredmeshes(coloredmeshes, pi/2, 1, 0, 0, style=style);
     rgl.viewpoint(0, 0, fov=0, interactive=FALSE);
     if(draw_labels) {
-        rgl::text3d(0,label_shift_y,0,"rostal");
+        rgl::text3d(0,label_shift_y,0,"rostral");
     }
 
     # Create the bottom central view.
@@ -329,3 +339,77 @@ brainview.t9 <- function(coloredmeshes, background="white", skip_all_na=TRUE, st
     return(invisible(coloredmeshes));
 }
 
+
+#' @title Visualize a list of colored meshes from a single defined angle.
+#'
+#' @param coloredmeshes, list of coloredmesh. A coloredmesh is a named list as returned by the `coloredmesh.from*` functions (like \code{\link[fsbrain]{coloredmesh.from.morph.native}}). It has the entries 'mesh' of type tmesh3d, a 'col', which is a color specification for such a mesh. Note that the `vis*` functions (like \code{\link[fsbrain]{vis.subject.morph.native}}) all return a list of coloredmeshes.
+#'
+#' @param view_angle character string, the view angle. One of 'lateral_lh', 'dorsal', 'lateral_rh', 'medial_lh', 'ventral', 'medial_rh', 'rostral' or 'caudal'. See \code{\link[fsbrain]{get.view.angle.names}}.
+#'
+#' @param background string, background color passed to \code{\link[rgl]{bg3d}}.
+#'
+#' @param skip_all_na logical, whether to skip (i.e., not render) meshes in the list that have the property 'morph_data_was_all_na' set to TRUE. Defaults to TRUE. Practically, this means that a hemisphere for which the data was not given is not rendered, instead of being rendered in a single color.
+#'
+#' @param style, a named list of style parameters or a string specifying an available style by name (e.g., 'shiny'). Defaults to 'default', the default style.
+#'
+#' @param rgloptions, named list. Parameters passed to \code{\link[rgl]{par3d}}. Defaults to the empty list. To increase plot resolution to 2000x1600 px, try: \code{rgloptions=list("windowRect"=c(50,50,2000,1600))}.
+#'
+#' @param rglactions, named list. A list in which the names are from a set of pre-defined actions. The values can be used to specify parameters for the action.
+#'
+#' @param draw_colorbar logical, whether to draw a colorbar. WARNING: The colorbar is drawn to a subplot, and this only works if there is enough space for it. You will have to increase the plot size using the 'rlgoptions' parameter for the colorbar to show up. Defaults to FALSE.
+#'
+#' @keywords internal
+#' @importFrom rgl open3d bg3d rgl.viewpoint
+brainview.sd <- function(coloredmeshes, view_angle, background="white", skip_all_na=TRUE, style="default", rgloptions = list(), rglactions = list(), draw_colorbar = FALSE) {
+
+
+    if(!is.list(coloredmeshes)) {
+        stop("Parameter 'coloredmeshes' must be a list.");
+    }
+
+    coloredmeshes = unify.coloredmeshes.colormaps(coloredmeshes);
+
+    hemi_sorted_cmeshes = sort.coloredmeshes.by.hemi(coloredmeshes);
+    lh_meshes = hemi_sorted_cmeshes$lh;
+    rh_meshes = hemi_sorted_cmeshes$rh;
+
+
+    rgl::open3d();
+    do.call(rgl::par3d, rgloptions);
+    Sys.sleep(1);
+    rgl::bg3d(background);
+
+
+    if(view_angle == "lateral_lh") {
+        vis.rotated.coloredmeshes(lh_meshes, pi/2, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl::rgl.viewpoint(-90, 0, fov=0, interactive=FALSE);
+    } else if (view_angle == "dorsal") {
+        vis.rotated.coloredmeshes(coloredmeshes, 0, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl::rgl.viewpoint(0, 0, fov=0, interactive=FALSE);
+    } else if(view_angle == "lateral_rh") {
+        vis.rotated.coloredmeshes(rh_meshes, pi/2, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl::rgl.viewpoint(90, 0, fov=0, interactive=FALSE);
+    } else if(view_angle == "medial_lh") {
+        vis.rotated.coloredmeshes(lh_meshes, pi/2, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl::rgl.viewpoint(90, 0, fov=0, interactive=FALSE);
+    } else if(view_angle == "ventral") {
+        vis.rotated.coloredmeshes(coloredmeshes, pi, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl::rgl.viewpoint(0, 0, fov=0, interactive=FALSE);
+    } else if(view_angle == "medial_rh") {
+        vis.rotated.coloredmeshes(rh_meshes, pi/2, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl::rgl.viewpoint(-90, 0, fov=0, interactive=FALSE);
+    } else if(view_angle == "rostral") {
+        vis.rotated.coloredmeshes(coloredmeshes, pi/2, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl.viewpoint(0, 0, fov=0, interactive=FALSE);
+    } else if(view_angle == "caudal") {
+        vis.rotated.coloredmeshes(coloredmeshes, pi/2, 1, 0, 0, style=style, draw_colorbar = draw_colorbar);
+        rgl::rgl.viewpoint(180, 0, fov=0, interactive=FALSE);
+    } else {
+        stop(sprintf("Invalid view_angle '%s'. Must be one of 'lateral_lh', 'dorsal', 'lateral_rh', 'medial_lh', 'ventral', 'medial_rh', 'rostral' or 'caudal'.\n", view_angle));
+    }
+
+    perform.rglactions(rglactions);
+
+    return(invisible(coloredmeshes));
+}
+
